@@ -36,14 +36,17 @@ class Branch(SubDir):
             yield t
 
     def get_tag(self, name: str, access_cb: Callable[[str], bool] = None) -> Tag:
-        if name in ("latest", "stable"):
+        if name in ("latest", "stable", "oldstable"):
             tags = list(self.get_tags(access_cb))
             tags.sort(key=Tag.creation_date, reverse=True)
+            first = True
             for t in tags:
                 if name == "latest":
                     return t
-                if t.is_released():
-                    return t
+                if t.is_stable():
+                    if name == "stable" or not first:
+                        return t
+                    first = False
             raise FileNotFoundError(name)
         return Tag(self, name)
 
