@@ -4,6 +4,7 @@
 
 import hashlib
 import os
+from typing import Callable
 
 from aiohttp import web
 
@@ -23,7 +24,7 @@ class ArtifactView(BaseView):
         yield "/%7e{user}/products/{product}/{variant}/{product_branch}/{version}/{format}/{artifact:.+}"
         yield "/%7E{user}/products/{product}/{variant}/{product_branch}/{version}/{format}/{artifact:.+}"
 
-    def _get_format(self, create=False):
+    def _get_format(self, create=False, access_cb: Callable[[str], bool] = None):
         match = self.request.match_info
         if "product" in match:
             if create:
@@ -33,14 +34,14 @@ class ArtifactView(BaseView):
                 .get_product(match["product"])
                 .get_variant(match["variant"])
                 .get_branch(match["product_branch"])
-                .get_version(match["version"])
+                .get_version(match["version"], access_cb)
                 .get_format(match["format"])
             )
         else:
             job = (
                 self.repo()
                 .get_branch(match["branch"])
-                .get_tag(match["tag"])
+                .get_tag(match["tag"], access_cb)
                 .get_job(match["job"])
             )
             fmt = job.get_format(match["format"])
@@ -73,7 +74,7 @@ class ArtifactView(BaseView):
                 raise web.HTTPUnprocessableEntity(reason=str(e)) from e
 
         else:
-            fmt = self._get_format()
+            fmt = self._get_format(access_cb=self.access_granted)
             artifact = self.request.match_info["artifact"]
             try:
                 filepath = fmt.get_filepath(artifact)
@@ -93,7 +94,7 @@ class ArtifactView(BaseView):
         )
 
     async def get(self):
-        fmt = self._get_format()
+        fmt = self._get_format(access_cb=self.access_granted)
         artifact = self.request.match_info["artifact"]
         try:
             filepath = fmt.get_filepath(artifact)
