@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: BSD-3-Clause
 
 import asyncio
+from typing import Callable
 
 from aiohttp import web
 import aiohttp_jinja2
@@ -26,11 +27,13 @@ class JobArchiveView(BaseView):
         return digests
 
     async def get(self):
-        job = _get_job(self.repo(), self.request)
+        job = _get_job(self.repo(), self.request, self.access_granted)
         url = job.url().rstrip("/") + ".tar"
         if url != self.request.path:
             raise web.HTTPFound(url)
-        return TarResponse(self._digests(job), job.path(), job.archive_name())
+        return TarResponse(
+            self._digests(job), job.path(), job.archive_name(), job.timestamp
+        )
 
 
 # --------------------------------------------------------------------------------------
@@ -46,7 +49,7 @@ class JobView(BaseView):
         """
         Get info about a job including metadata and artifact formats.
         """
-        job = _get_job(self.repo(), self.request)
+        job = _get_job(self.repo(), self.request, self.access_granted)
         if not job.exists():
             raise web.HTTPNotFound()
         if job.url() != self.request.path:
@@ -141,14 +144,17 @@ class JobView(BaseView):
 
 
 # --------------------------------------------------------------------------------------
-def _get_job(repo, request):
+def _get_job(repo, request, access_cb: Callable[[str], bool] = None):
     match_info = request.match_info
-    if match_info["tag"] in ("latest", "stable") and request.method != "GET":
+    if (
+        match_info["tag"] in ("latest", "stable", "oldstable")
+        and request.method != "GET"
+    ):
         raise web.HTTPMethodNotAllowed(request.method, ["GET"])
     try:
         return (
             repo.get_branch(match_info["branch"])
-            .get_tag(match_info["tag"])
+            .get_tag(match_info["tag"], access_cb)
             .get_job(match_info["job"])
         )
     except FileNotFoundError as e:
