@@ -96,3 +96,21 @@ async def test_read_denied(dlrepo_server):
     async with aiohttp.ClientSession(url, auth=auth) as sess:
         resp = await sess.get("/branches/main/tag/job/format/file.txt")
         assert resp.status == 401
+
+
+async def test_acl_regexp(dlrepo_server):
+    url, _ = dlrepo_server
+    auth = aiohttp.BasicAuth("coin", "coin")
+    async with aiohttp.ClientSession(url, auth=auth) as sess:
+        data = b"content"
+        digest = hashlib.sha256(data).hexdigest()
+        resp = await sess.put(
+            "/branches/main/tag2/job/format/file2.txt",
+            data=data,
+            headers={"Digest": f"sha256:{digest}"},
+        )
+        assert resp.status == 201
+        resp = await sess.get("/branches/main/tag2/job/format/file2.txt")
+        assert resp.status == 200
+        data = await resp.read()
+        assert data == b"content"
